@@ -1,9 +1,9 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "llama" "1.0.4"
+(define-package "llama" "20251101.2002"
   "Compact syntax for short lambda."
   '((emacs  "26.1")
     (compat "30.1"))
   :url "https://github.com/tarsius/llama"
-  :commit "d430d48e0b5afd2a34b5531f103dcb110c3539c4"
-  :revdesc "v1.0.4-0-gd430d48e0b5a"
+  :commit "e4803de8ab85991b6a944430bb4f543ea338636d"
+  :revdesc "e4803de8ab85"
   :keywords '("extensions"))
